@@ -8,7 +8,7 @@ use Data::Dumper;
 use Carp;
 use Log::LTSV::Instance::Flatten;
 
-our $VERSION = "0.04";
+our $VERSION = "0.05";
 
 my %LOG_LEVEL_MAP = (
     DEBUG    => 1,
@@ -69,8 +69,8 @@ sub sticks {
 sub _escape {
     my ($self, $val) = @_;
 
-    $val =~ s/\t/\\t/;
-    $val =~ s/\n/\\n/;
+    $val =~ s/\t/\\t/g;
+    $val =~ s/\n/\\n/g;
 
     return $val;
 }
